@@ -101,11 +101,30 @@ degrees_of_freedom.default <- function(model, method = "analytical", ...) {
 dof <- degrees_of_freedom
 
 
+#' @export
+degrees_of_freedom.merModList <- function(model,...) {
+  s <- suppressWarnings(summary(model))
+  s$fe$df
+}
+
+
 #' @export
 degrees_of_freedom.emmGrid <- function(model,...) {
   summary(model)$df
 }
 
+#' @export
+degrees_of_freedom.emm_list <- function(model,...) {
+  s <- summary(model)
+  unname(unlist(lapply(s, function(i) {
+    if (is.null(i$df)) {
+      Inf
+    } else {
+      i$df
+    }
+  })))
+}
+
 #' @export
 degrees_of_freedom.glht <- function(model,...) {
   model$df
@@ -125,6 +144,22 @@ degrees_of_freedom.mipo <- function(model,...) {
   as.vector(summary(model)$df)
 }
 
+#' @export
+degrees_of_freedom.mira <- function(model,...) {
+  if (!requireNamespace("mice", quietly = TRUE)) {
+    stop("Package 'mice' needed for this function to work. Please install it.")
+  }
+  degrees_of_freedom(mice::pool(model), ...)
+}
+
+#' @export
+degrees_of_freedom.vgam <- function(model,...) {
+  params <- insight::get_parameters(model)
+  out <- setNames(rep(NA, nrow(params)), params$Parameter)
+  out[names(model@nl.df)] <- model@nl.df
+  out
+}
+
 #' @export
 degrees_of_freedom.logitor <- function(model,...) {
   degrees_of_freedom.default(model$fit, ...)
@@ -168,6 +203,10 @@ degrees_of_freedom.betamfx <- degrees_of_freedom.logitor
   nparam <- n_parameters(model)
   n <- insight::n_obs(model)
 
+  if (is.null(n)) {
+    n <- Inf
+  }
+
   if (isTRUE(kenward) && inherits(model, "lmerMod")) {
     dof <- as.numeric(dof_kenward(model))
   } else {
