@@ -9,12 +9,12 @@
 #' @param standardize The method used for standardizing the parameters. Can be \code{"refit"}, \code{"posthoc"}, \code{"smart"}, \code{"basic"} or \code{NULL} (default) for no standardization. See 'Details' in \code{\link[effectsize]{standardize_parameters}}. Note that robust estimation (i.e. \code{robust=TRUE}) of standardized parameters only works when \code{standardize="refit"}.
 #' @param exponentiate Logical, indicating whether or not to exponentiate the the coefficients (and related confidence intervals). This is typical for, say, logistic regressions, or more generally speaking: for models with log or logit link. \strong{Note:} standard errors are also transformed (by multiplying the standard errors with the exponentiated coefficients), to mimic behaviour of other software packages, such as Stata.
 #' @param robust Logical, if \code{TRUE}, robust standard errors are calculated (if possible), and confidence intervals and p-values are based on these robust standard errors. Additional arguments like \code{vcov_estimation} or \code{vcov_type} are passed down to other methods, see \code{\link[=standard_error_robust]{standard_error_robust()}} for details.
-#' @param component Model component for which parameters should be shown. May be one of \code{"conditional"}, \code{"precision"} (\pkg{betareg}), \code{"scale"} (\pkg{ordinal}), \code{"extra"} (\pkg{glmx}), \code{"marginal"} (\pkg{mfx}) or \code{"all"}.
+#' @param component Model component for which parameters should be shown. May be one of \code{"conditional"}, \code{"precision"} (\pkg{betareg}), \code{"scale"} (\pkg{ordinal}), \code{"extra"} (\pkg{glmx}), \code{"marginal"} (\pkg{mfx}), \code{"conditional"} or \code{"full"} (for \code{MuMIn::model.avg()}) or \code{"all"}.
 #' @param p_adjust Character vector, if not \code{NULL}, indicates the method to adjust p-values. See \code{\link[stats]{p.adjust}} for details.
 #' @param df_method Method for computing degrees of freedom for confidence intervals (CI). Only applies to models of class \code{glm} or \code{polr}. May be \code{"profile"} or \code{"wald"}.
 #' @param ... Arguments passed to or from other methods. For instance, when \code{bootstrap = TRUE}, arguments like \code{ci_method} are passed down to \code{\link[bayestestR]{describe_posterior}}.
 #'
-#' @seealso \code{\link[=standardize_names]{standardize_names()}} to rename
+#' @seealso \code{\link[insight:standardize_names]{standardize_names()}} to rename
 #'   columns into a consistent, standardized naming scheme.
 #'
 #' @examples
@@ -75,7 +75,7 @@ model_parameters.default <- function(model, ci = .95, bootstrap = FALSE, iterati
   }
 
   if (exponentiate) params <- .exponentiate_parameters(params)
-  params <- .add_model_parameters_attributes(params, model, ci, exponentiate, ...)
+  params <- .add_model_parameters_attributes(params, model, ci, exponentiate, bootstrap, iterations, ...)
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
@@ -133,121 +133,53 @@ model_parameters.mle <- model_parameters.glm
 # other special cases ------------------------------------------------
 
 
-#' @export
-model_parameters.averaging <- function(model, ci = .95, component = c("conditional", "full"), exponentiate = FALSE, p_adjust = NULL, ...) {
-  component <- match.arg(component)
-  out <- .model_parameters_generic(
-    model = model,
-    ci = ci,
-    merge_by = "Parameter",
-    exponentiate = exponentiate,
-    component = component,
-    p_adjust = p_adjust,
-    ...
-  )
-
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  out
-}
-
-
-
-#' @rdname model_parameters.default
-#' @export
-model_parameters.betareg <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("conditional", "precision", "all"), standardize = NULL, exponentiate = FALSE, p_adjust = NULL, ...) {
-  component <- match.arg(component)
-  if (component == "all") {
-    merge_by <- c("Parameter", "Component")
-  } else {
-    merge_by <- "Parameter"
-  }
-
-  ## TODO check merge by
-
-  out <- .model_parameters_generic(
-    model = model,
-    ci = ci,
-    component = component,
-    bootstrap = bootstrap,
-    iterations = iterations,
-    merge_by = c("Parameter", "Component"),
-    standardize = standardize,
-    exponentiate = exponentiate,
-    p_adjust = p_adjust,
-    ...
-  )
-
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  out
-}
-
-
-
-#' @rdname model_parameters.default
-#' @export
-model_parameters.clm2 <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("all", "conditional", "scale"), standardize = NULL, exponentiate = FALSE, p_adjust = NULL, ...) {
-  component <- match.arg(component)
-  if (component == "all") {
-    merge_by <- c("Parameter", "Component")
-  } else {
-    merge_by <- "Parameter"
-  }
-
-  ## TODO check merge by
-
-  out <- .model_parameters_generic(
-    model = model,
-    ci = ci,
-    component = component,
-    bootstrap = bootstrap,
-    iterations = iterations,
-    merge_by = c("Parameter", "Component"),
-    standardize = standardize,
-    exponentiate = exponentiate,
-    p_adjust = p_adjust,
-    ...
-  )
-
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  out
-}
-
-
-#' @export
-model_parameters.clmm2 <- model_parameters.clm2
-
-
-#' @rdname model_parameters.default
-#' @export
-model_parameters.glmx <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("all", "conditional", "extra"), standardize = NULL, exponentiate = FALSE, p_adjust = NULL, ...) {
-  component <- match.arg(component)
-  if (component == "all") {
-    merge_by <- c("Parameter", "Component")
-  } else {
-    merge_by <- "Parameter"
-  }
-
-  out <- .model_parameters_generic(
-    model = model,
-    ci = ci,
-    component = component,
-    bootstrap = bootstrap,
-    iterations = iterations,
-    merge_by = merge_by,
-    standardize = standardize,
-    exponentiate = exponentiate,
-    p_adjust = p_adjust,
-    ...
-  )
-
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  out
-}
-
-
-
 #' @export
 model_parameters.sem <- model_parameters.default
 
+#' @export
+model_parameters.HLfit <- model_parameters.default
+
 #' @export
 model_parameters.mipo <- model_parameters.default
+
+#' @export
+model_parameters.margins <- function(model, ci = .95, exponentiate = FALSE, p_adjust = NULL, ...) {
+  # Parameters, Estimate and CI
+  params <- insight::get_parameters(model)
+  params <- .data_frame(
+    params,
+    SE = summary(model)$SE
+  )
+
+  # CI
+  params <- merge(params, ci(model, ci = ci), by = "Parameter", sort = FALSE)
+
+  # Statistic
+  statistic <- insight::get_statistic(model)
+  params <- merge(params, statistic, by = "Parameter", sort = FALSE)
+
+  # Statistic
+  params <- .data_frame(params, p = summary(model)$p)
+
+  # ==== Renaming
+
+  if ("Statistic" %in% names(params)) {
+    names(params) <- gsub("Statistic", gsub("(-|\\s)statistic", "", attr(statistic, "statistic", exact = TRUE)), names(params))
+    names(params) <- gsub("chi-squared", "Chi2", names(params))
+  }
+  names(parameters) <- gsub("(c|C)hisq", "Chi2", names(parameters))
+  names(params) <- gsub("Estimate", "Coefficient", names(params))
+
+  # ==== adjust p-values?
+
+  if (!is.null(p_adjust) && tolower(p_adjust) %in% stats::p.adjust.methods && "p" %in% colnames(params)) {
+    params$p <- stats::p.adjust(params$p, method = p_adjust)
+  }
+
+  if (exponentiate) params <- .exponentiate_parameters(params)
+  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  params <- .add_model_parameters_attributes(params, model, ci, exponentiate, ...)
+  class(params) <- c("parameters_model", "see_parameters_model", class(params))
+
+  params
+}
