@@ -7,13 +7,13 @@
 #'
 #' @examples
 #' \donttest{
-#' library(lme4)
-#' model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
-#' p_value_wald(model)
-#' ci_wald(model, ci = c(0.90, 0.95))
+#' if (require("lme4")) {
+#'   model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
+#'   p_value_wald(model)
+#'   ci_wald(model, ci = c(0.90, 0.95))
 #' }
-#'
-#' @return The p-values.
+#' }
+#' @return A data frame.
 #' @importFrom stats coef pt
 #' @references Barr, D. J. (2013). Random effects structure for testing interactions in linear mixed-effects models. Frontiers in psychology, 4, 328.
 #' @export
@@ -30,6 +30,20 @@ p_value_wald.merMod <- function(model, dof = Inf, ...) {
 }
 
 
+#' @export
+p_value_wald.HLfit <- function(model, dof = Inf, ...) {
+  utils::capture.output(params <- as.data.frame(summary(model)$beta_table))
+  .p_value_wald(params, dof)
+}
+
+
+#' @export
+p_value_wald.merModList <- function(model, dof = Inf, ...) {
+  params <- suppressWarnings(summary(model))
+  .p_value_wald(params$fe, dof)
+}
+
+
 #' @export
 p_value_wald.rlmerMod <- function(model, dof = Inf, ...) {
   params <- as.data.frame(stats::coef(summary(model)))
@@ -52,6 +66,10 @@ p_value_wald.cpglmm <- function(model, dof = Inf, ...) {
 
   if ("t value" %in% names(params)) {
     p <- 2 * stats::pt(abs(params[, "t value"]), df = dof, lower.tail = FALSE)
+  } else if ("t-value" %in% names(params)) {
+    p <- 2 * stats::pt(abs(params[, "t-value"]), df = dof, lower.tail = FALSE)
+  } else if ("statistic" %in% names(params)) {
+    p <- 2 * stats::pt(abs(params[, "statistic"]), df = dof, lower.tail = FALSE)
   } else if ("z value" %in% names(params)) {
     p <- 2 * stats::pt(abs(params[, "z value"]), df = dof, lower.tail = FALSE)
   } else {
