@@ -77,6 +77,39 @@ simulate_parameters.default <- function(model, iterations = 1000, centrality = "
 
 
 
+#' @export
+simulate_parameters.zeroinfl <- function(model, iterations = 1000, centrality = "median", ci = .95, ci_method = "quantile", test = "p-value", ...) {
+  data <- simulate_model(model, iterations = iterations, ...)
+  out <- .summary_bootstrap(data = data, test = test, centrality = centrality, ci = ci, ci_method = ci_method, ...)
+
+  params <- insight::get_parameters(model)
+  if ("Effects" %in% colnames(params) && .n_unique(params$Effects) > 1) {
+    out$Effects <- params$Effects
+  }
+
+  if ("Component" %in% colnames(params) && .n_unique(params$Component) > 1) {
+    out$Component <- params$Component
+  }
+
+  if (inherits(model, c("zeroinfl", "hurdle", "zerocount"))) {
+    out$Parameter <- gsub("^(count_|zero_)", "", out$Parameter)
+  }
+
+  class(out) <- c("parameters_simulate", "see_parameters_simulate", class(out))
+  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "iterations") <- iterations
+  attr(out, "ci") <- ci
+
+  out
+}
+
+#' @export
+simulate_parameters.hurdle <- simulate_parameters.zeroinfl
+
+#' @export
+simulate_parameters.zerocount <- simulate_parameters.zeroinfl
+
+
 #' @export
 simulate_parameters.multinom <- function(model, iterations = 1000, centrality = "median", ci = .95, ci_method = "quantile", test = "p-value", ...) {
   data <- simulate_model(model, iterations = iterations, ...)
@@ -120,3 +153,26 @@ simulate_parameters.glmmTMB <- function(model, iterations = 1000, centrality = "
 
   out
 }
+
+
+
+#' @export
+simulate_parameters.mlm <- function(model, iterations = 1000, centrality = "median", ci = .95, ci_method = "quantile", test = "p-value", ...) {
+  data <- simulate_model(model, iterations = iterations, ...)
+  out <- .summary_bootstrap(data = data, test = test, centrality = centrality, ci = ci, ci_method = ci_method, ...)
+
+  out$Response <- NA
+  responses <- insight::find_response(model, combine = FALSE)
+  for (i in responses) {
+    out$Response[grepl(paste0(i, "$"), out$Parameter)] <- i
+    out$Parameter <- gsub(paste0(i, "$"), "", out$Parameter)
+  }
+
+  class(out) <- c("parameters_simulate", "see_parameters_simulate", class(out))
+  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_class") <- class(model)
+  attr(out, "iterations") <- iterations
+  attr(out, "ci") <- ci
+
+  out
+}
