@@ -11,7 +11,10 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
 
       test_that("model_parameters.aov", {
         model <- aov(Sepal.Width ~ Species, data = iris)
-        testthat::expect_equal(sum(model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE)$df), 149)
+        mp <- model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE)
+        testthat::expect_equal(sum(mp$df), 149)
+        testthat::expect_equal(colnames(mp), c("Parameter", "Sum_Squares", "df", "Mean_Square", "F", "p",
+                                               "Omega2_partial", "Eta2_partial", "Epsilon2"))
 
         model <- aov(Sepal.Length ~ Species * Cat1 * Cat2, data = iris)
         testthat::expect_equal(sum(model_parameters(model, omega_squared = "raw", eta_squared = "partial", epsilon_squared = TRUE)$df), 149)
