@@ -1,7 +1,8 @@
 if (require("testthat") &&
   require("parameters") &&
   require("sandwich") &&
-  require("clubSandwich") &&
+  ## TODO enable when clubSandwich back on CRAN
+  # require("clubSandwich") &&
   require("effectsize")) {
 
   data(mtcars)
@@ -32,21 +33,22 @@ if (require("testthat") &&
   })
 
 
+  ## TODO enable when clubSandwich back on CRAN
 
   # cluster-robust standard errors, using clubSandwich
-  data(iris)
-  model <- lm(Petal.Length ~ Sepal.Length * Species, data = iris)
-  iris$cluster <- factor(rep(LETTERS[1:8], length.out = nrow(iris)))
-
-  test_that("model_parameters, robust CR", {
-    params <- model_parameters(model, robust = TRUE, vcov_estimation = "CR", vcov_type = "CR1", vcov_args = list(cluster = iris$cluster))
-    robust_se <- unname(sqrt(diag(clubSandwich::vcovCR(model, type = "CR1", cluster = iris$cluster))))
-    expect_equal(params$SE, robust_se, tolerance = 1e-3)
-    expect_equal(params$p, c(0.01246, 0.04172, 0.18895, 0.57496, 0, 0), tolerance = 1e-3)
-  })
-
-  test_that("model_parameters, normal", {
-    params <- model_parameters(model)
-    expect_equal(params$p, c(0.13267, 0.21557, 0.36757, 0.77012, 3e-05, 0), tolerance = 1e-3)
-  })
+  # data(iris)
+  # model <- lm(Petal.Length ~ Sepal.Length * Species, data = iris)
+  # iris$cluster <- factor(rep(LETTERS[1:8], length.out = nrow(iris)))
+  #
+  # test_that("model_parameters, robust CR", {
+  #   params <- model_parameters(model, robust = TRUE, vcov_estimation = "CR", vcov_type = "CR1", vcov_args = list(cluster = iris$cluster))
+  #   robust_se <- unname(sqrt(diag(clubSandwich::vcovCR(model, type = "CR1", cluster = iris$cluster))))
+  #   expect_equal(params$SE, robust_se, tolerance = 1e-3)
+  #   expect_equal(params$p, c(0.01246, 0.04172, 0.18895, 0.57496, 0, 0), tolerance = 1e-3)
+  # })
+  #
+  # test_that("model_parameters, normal", {
+  #   params <- model_parameters(model)
+  #   expect_equal(params$p, c(0.13267, 0.21557, 0.36757, 0.77012, 3e-05, 0), tolerance = 1e-3)
+  # })
 }
